@@ -1,5 +1,5 @@
 """
-Plotting helpers for :obj:`ScmRun`
+Plotting helpers for :class:`ScmRun <scmdata.run.ScmRun>`
 
 See the example notebook 'plotting-with-seaborn.ipynb' for usage examples
 """
@@ -44,19 +44,28 @@ RCMIP_SCENARIO_COLOURS = {
 
 def lineplot(self, time_axis=None, **kwargs):  # pragma: no cover
     """
-    Make a line plot via `seaborn's lineplot <https://seaborn.pydata.org/generated/seaborn.lineplot.html>`_
+    Make a line plot via `seaborn's lineplot
+    <https://seaborn.pydata.org/generated/seaborn.lineplot.html>`_
 
     If only a single unit is present, it will be used as the y-axis label.
     The axis object is returned so this can be changed by the user if desired.
 
     Parameters
     ----------
-    time_axis : {None, "year", "year-month", "days since 1970-01-01", "seconds since 1970-01-01"}
-        Time axis to use for the plot. If `None`, :class:`datetime.datetime` objects will be used.
-        If `"year"`, the year of each time point  will be used. If `"year-month", the year plus
-        (month - 0.5) / 12  will be used. If `"days since 1970-01-01"`, the number of days  since 1st
-        Jan 1970 will be used (calculated using the ``datetime``  module). If `"seconds since 1970-01-01"`,
-        the number of seconds  since 1st Jan 1970 will be used (calculated using the ``datetime`` module).
+    time_axis : {None, "year", "year-month", "days since 1970-01-01", "seconds since 1970-01-01"}  # noqa: E501
+        Time axis to use for the plot.
+
+        If ``None``, :class:`datetime.datetime` objects will be used.
+
+        If ``"year"``, the year of each time point  will be used.
+
+        If ``"year-month"``, the year plus (month - 0.5) / 12  will be used.
+
+        If ``"days since 1970-01-01"``, the number of days since 1st Jan 1970 will be
+        used (calculated using the :mod:`datetime` module).
+
+        If ``"seconds since 1970-01-01"``, the number of seconds  since 1st Jan 1970 will
+        be used (calculated using the :mod:`datetime` module).
 
     **kwargs
         Keyword arguments to be passed to ``seaborn.lineplot``. If none are passed,
@@ -64,7 +73,7 @@ def lineplot(self, time_axis=None, **kwargs):  # pragma: no cover
 
     Returns
     -------
-    :obj:`matplotlib.axes._subplots.AxesSubplot`
+    :class:`matplotlib.axes._subplots.AxesSubplot`
         Output of call to ``seaborn.lineplot``
     """
     if not has_seaborn:
@@ -93,7 +102,7 @@ def lineplot(self, time_axis=None, **kwargs):  # pragma: no cover
 def plumeplot(  # pragma: no cover
     self,
     ax=None,
-    quantiles_plumes=[((0.05, 0.95), 0.5), ((0.5,), 1.0),],
+    quantiles_plumes=[((0.05, 0.95), 0.5), ((0.5,), 1.0)],
     hue_var="scenario",
     hue_label="Scenario",
     palette=None,
@@ -110,7 +119,7 @@ def plumeplot(  # pragma: no cover
 
     Parameters
     ----------
-    ax : :obj:`matplotlib.axes._subplots.AxesSubplot`
+    ax : :class:`matplotlib.axes._subplots.AxesSubplot`
         Axes on which to make the plot
 
     quantiles_plumes : list[tuple[tuple, float]]
@@ -162,7 +171,7 @@ def plumeplot(  # pragma: no cover
 
     Returns
     -------
-    :obj:`matplotlib.axes._subplots.AxesSubplot`, list
+    :class:`matplotlib.axes._subplots.AxesSubplot`, list
         Axes on which the plot was made and the legend items we have made (in
         case the user wants to move the legend to a different position for
         example)
@@ -336,7 +345,8 @@ def plumeplot(  # pragma: no cover
     else:
         if dashes is not None:
             warnings.warn(
-                "`dashes` was passed but no lines were plotted, the style settings will not be used"
+                "`dashes` was passed but no lines were plotted, the style settings "
+                "will not be used"
             )
 
     ax.legend(handles=legend_items, loc="best")
@@ -372,7 +382,8 @@ def _get_1d_or_raise(in_scmrun, hue_var, style_var):
 
 def _deprecated_line_plot(self, **kwargs):  # pragma: no cover
     """
-    Make a line plot via `seaborn's lineplot <https://seaborn.pydata.org/generated/seaborn.lineplot.html>`_
+    Make a line plot via
+    `seaborn's lineplot <https://seaborn.pydata.org/generated/seaborn.lineplot.html>`_
 
     Deprecated: use :func:`lineplot` instead
 
@@ -384,7 +395,7 @@ def _deprecated_line_plot(self, **kwargs):  # pragma: no cover
 
     Returns
     -------
-    :obj:`matplotlib.axes._subplots.AxesSubplot`
+    :class:`matplotlib.axes._subplots.AxesSubplot`
         Output of call to ``seaborn.lineplot``
     """
     warnings.warn("Use lineplot instead", DeprecationWarning)
